@@ -246,7 +246,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		#счетчик трафика
 		if (self.rx1/1024) > 1048576:
-			self.frm.lblInputValue.setText( "%.2f TB"%((self.rx1/1048576.0)/1024.0) )
+			self.frm.lblInputValue.setText( "%.2f GB"%((self.rx1/1048576.0)/1024.0) )
 		elif self.rx1 > 1048576:
 			self.frm.lblInputValue.setText( "%.2f MB"%(self.rx1/1048576.0) )
 		elif self.rx1 > 1024:
@@ -255,7 +255,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 			self.frm.lblInputValue.setText( "%s B"%(self.rx1) )
 		
 		if (self.tx1/1024) > 1048576:
-			self.frm.lblOutputValue.setText( "%.2f TB"%((self.tx1/1048576.0)/1024.0) )
+			self.frm.lblOutputValue.setText( "%.2f GB"%((self.tx1/1048576.0)/1024.0) )
 		elif self.tx1 > 1048576:
 			self.frm.lblOutputValue.setText( "%.2f MB"%(self.tx1/1048576.0) )
 		elif self.tx1 > 1024:
