@@ -571,10 +571,12 @@ class MyDB:
 		try:
 			self.cur.execute( SQL )
 			ret = self.cur.fetchone()[0]
+			if ret == 1:
+				ret = True
 			if ret == None:
 				raise
 		except Exception, E:
 			print "MyDB::isAutoRecEnable(): [%s] %s\n"%(SQL,E)
-			ret = 0
+			ret = False
 
 		return ret
